// LIO 2010-03-10 v27

#ifndef DEBUG
#define DPRINTF(...)
#else
#define DPRINTF(...) fprintf(stderr, __VA_ARGS__)
#endif

#include <algorithm>
#include <climits>
#include <cstdio>
#include <cstring>
using namespace std;

struct tower { int x, y, i; };

struct ltx
{
	bool (operator ())(tower a, tower b) const { return a.x < b.x || a.x == b.x && a.y < b.y; }
};

struct lty
{
	bool (operator ())(tower a, tower b) const { return a.y < b.y || a.y == b.y && a.x < b.x; }
};

static tower towersx[100000], towersy[100000], *txend, *tyend;
static bool visited[100000] = { 0 };

static struct move { int x1, y1, x2, y2; } moves[200000];
static move *mend = moves;

static int n = 0;

static __attribute__ ((fastcall)) void dfs(tower self)
{
	DPRINTF("%u\n", self.i);
	visited[self.i] = true;
	++n;

	// Horizontal
	tower *p = lower_bound(towersx, txend, self, ltx());

	if (p > towersx && p[-1].x == self.x && !visited[p[-1].i])
	{
		dfs(p[-1]);
		*mend++ = (move) { p[-1].x, p[-1].y, self.x, self.y };
	}

	if (p + 1 < txend && p[1].x == self.x && !visited[p[1].i])
	{
		dfs(p[1]);
		*mend++ = (move) { p[1].x, p[1].y, self.x, self.y };
	}

	// Vertical
	p = lower_bound(towersy, tyend, self, lty());

	if (p > towersy && p[-1].y == self.y && !visited[p[-1].i])
	{
		dfs(p[-1]);
		*mend++ = (move) { p[-1].x, p[-1].y, self.x, self.y };
	}

	if (p + 1 < tyend && p[1].y == self.y && !visited[p[1].i])
	{
		dfs(p[1]);
		*mend++ = (move) { p[1].x, p[1].y, self.x, self.y };
	}
}

int main()
{
	FILE *f = fopen("torni.dat", "r");

	int k;
	fscanf(f, "%u", &k);

	for (int i = 0; i < k; ++i)
	{
		fscanf(f, "%u%u", &towersx[i].x, &towersx[i].y);
	}

	txend = towersx + k;
	tyend = towersy + k;
	sort(towersx, txend, ltx());

	for (int i = 0; i < k; ++i)
	{
		towersx[i].i = i;
	}

	memcpy(towersy, towersx, k * sizeof towersx[0]);
	sort(towersy, tyend, lty());

	int m = 0;

	tower newtowers[100000];
	tower *ntend = newtowers;

	for (int i = 0; i < k; ++i)
	{
		if (!visited[i])
		{
			int oldn = n;
			dfs(towersx[i]);
			m += n - oldn + 1;
			*ntend++ = towersx[i];
		}
	}

	sort(newtowers, ntend, ltx());

	freopen("torni.rez", "w", f);
	fprintf(f, "%u\n", m - 2);

	for (move *p = moves; p != mend; ++p)
	{
		fprintf(f, "%i %i %i %i\n", p->x1, p->y1, p->x2, p->y2);
	}

	for (tower *p = newtowers + 1; p != ntend; ++p)
	{
		fprintf(f, "%i %i %i %i\n", p[-1].x, p[-1].y, p->x, p[-1].y);
		fprintf(f, "%i %i %i %i\n", p->x, p[-1].y, p->x, p->y);
	}

	fclose(f);
	return 0;
}
