// LIO 2010-03-10 v27

#ifndef DEBUG
#define DPRINTF(...)
#else
#define DPRINTF(...) fprintf(stderr, __VA_ARGS__)
#endif

#include <limits.h>
#include <stdio.h>
#include <string.h>

int main()
{
	FILE *f = fopen("udens.dat", "r");

	int n, p, t;
	fscanf(f, "%u%u%u", &n, &p, &t);

	int w[100000];

	for (int i = 0; i < n; ++i)
	{
		fscanf(f, "%u", &w[i]);
	}

	// h[i] = left from i
	// h[i+1] = right from i
	int h[100001];
	h[0] = h[n] = INT_MAX;

	for (int i = 1; i < n; ++i)
	{
		fscanf(f, "%u", &h[i]);
	}

	struct node { int st, en, w, h; } stack[100000];
	struct node *top = stack;
	stack[0].st = (stack[0].en = p) - 1;
	stack[0].w = w[p - 1];
	stack[0].h = 0;

	_Bool visited[100000] = { 0 };
	visited[p - 1] = 1;

	int elapsed = 0;

	while (top->st || top->en < n)
	{
		DPRINTF("[%u, %u): w=%u, h=%u, t=%u\n", top->st, top->en, top->w, top->h, elapsed);

		int minh = h[top->st];
		if (h[top->en] < minh) minh = h[top->en];

		unsigned long long vol = (unsigned long long) top->w * (minh - top->h);

		if (elapsed + vol >= t)
		{
			break;
		}

		elapsed += vol;
		top->h = minh;

		if (h[top->st] < h[top->en])
		{
			int i = top->st - 1;

			if (!visited[i])
			{
				visited[i] = 1;
				++top;
				top->st = i;
				top->en = i + 1;
				top->w = w[i];
				top->h = 0;
			}
			else
			{
				register int w = top->w, x = top->en;
				--top;
				top->en = x;
				top->w += w;
			}
		}
		else
		{
			int i = top->en;

			if (!visited[i])
			{
				visited[i] = 1;
				++top;
				top->st = i;
				top->en = i + 1;
				top->w = w[i];
				top->h = 0;
			}
			else
			{
				register int w = top->w, x = top->st;
				--top;
				top->st = x;
				top->w += w;
			}
		}
	}

	DPRINTF("[%u, %u): w=%u, h=%u, t=%u\n", top->st, top->en, top->w, top->h, elapsed);

	freopen("udens.rez", "w", f);

	memset(h, 0, n * sizeof h[0]);

	for (struct node *p = stack; p < top; ++p)
	{
		for (int i = p->st; i < p->en; ++i)
		{
			h[i] = p->h;
		}
	}

	for (int i = 0; i < top->st; ++i)
	{
		fprintf(f, "%u 1\n", h[i] * w[i]);
	}

	int num = t - elapsed, den = top->w;

	for (int i = top->st; i < top->en; ++i)
	{
		unsigned long long truenum = ((unsigned long long) top->h * top->w + num) * w[i];
		int gcd = den;

		for (int b = truenum % den; b; )
		{
			int temp = gcd % b;
			gcd = b;
			b = temp;
		}

		fprintf(f, "%I64u %u\n", truenum / gcd, den / gcd);
	}

	for (int i = top->en; i < n; ++i)
	{
		fprintf(f, "%u 1\n", h[i] * w[i]);
	}

	fclose(f);
	return 0;
}
